@@ -1,12 +1,9 @@
-import os
 import abc
-
-__metaclass__ = type
+import os
 
 
 class Credential(metaclass=abc.ABCMeta):
-    """Abstract class to manage credentials
-    """
+    """Abstract class to manage credentials"""
 
     @abc.abstractproperty
     def username(self):
@@ -18,8 +15,7 @@ class Credential(metaclass=abc.ABCMeta):
 
 
 class SimpleCredential(Credential):
-    """Simple credentials implementation
-    """
+    """Simple credentials implementation"""
 
     def __init__(self, username, password):
         self._username = username
@@ -35,20 +31,34 @@ class SimpleCredential(Credential):
 
 
 class EnvironCredential(Credential):
-    """Source credentials from environment variables.
-       Actual sourcing is deferred until requested.
+    """
+    Source credentials from environment variables.
+
+    Actual sourcing is deferred until requested.
+
+    Supports comparison by equality.
+
+    >>> e1 = EnvironCredential('a', 'b')
+    >>> e2 = EnvironCredential('a', 'b')
+    >>> e3 = EnvironCredential('a', 'c')
+    >>> e1 == e2
+    True
+    >>> e2 == e3
+    False
     """
 
     def __init__(self, user_env_var, pwd_env_var):
         self.user_env_var = user_env_var
         self.pwd_env_var = pwd_env_var
 
+    def __eq__(self, other: object) -> bool:
+        return vars(self) == vars(other)
+
     def _get_env(self, env_var):
-        """Helper to read an environment variable
-        """
+        """Helper to read an environment variable"""
         value = os.environ.get(env_var)
         if not value:
-            raise ValueError('Missing environment variable:%s' % env_var)
+            raise ValueError(f'Missing environment variable:{env_var}')
         return value
 
     @property
