@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
 Common test functionality for backends.
 """
@@ -9,10 +7,9 @@ import string
 
 import pytest
 
-from .util import random_string
 from keyring import errors
 
-__metaclass__ = type
+from .util import random_string
 
 # unicode only characters
 # Sourced from The Quick Brown Fox... Pangrams
@@ -73,6 +70,12 @@ class BackendBasicTests:
         service = random_string(20)
         self.check_set_get(service, username, password)
 
+    def test_set_after_set_blank(self):
+        service = random_string(20)
+        username = random_string(20)
+        self.keyring.set_password(service, username, "")
+        self.keyring.set_password(service, username, "non-blank")
+
     def test_difficult_chars(self):
         password = random_string(20, self.DIFFICULT_CHARS)
         username = random_string(20, self.DIFFICULT_CHARS)
@@ -165,3 +168,10 @@ class BackendBasicTests:
         monkeypatch.setattr(os, 'environ', env)
         self.keyring.set_properties_from_env()
         assert self.keyring.foo_bar == 'fizz buzz'
+
+    def test_new_with_properties(self):
+        alt = self.keyring.with_properties(foo='bar')
+        assert alt is not self.keyring
+        assert alt.foo == 'bar'
+        with pytest.raises(AttributeError):
+            self.keyring.foo  # noqa: B018
